@@ -1,7 +1,6 @@
 from botrun_flow_lang.models.nodes.base_node import BaseNode, BaseNodeData, NodeType
 from botrun_flow_lang.models.nodes.event import (
     NodeEvent,
-    NodeRunStreamEvent,
     NodeRunCompletedEvent,
 )
 from typing import Dict, Any, AsyncGenerator
@@ -33,17 +32,10 @@ class AnswerNode(BaseNode):
             self.data.input_variables[0].variable_name, ""
         )
 
-        # # 如果LLM输出是流式的，我们可以直接传递它
-        # if isinstance(llm_output, AsyncGenerator):
-        #     async for chunk in llm_output:
-        #         yield NodeRunStreamEvent(node_id=self.data.id, chunk=chunk)
-        # else:
-        #     # 如果不是流式的，我们可以一次性发送整个答案
-        #     yield NodeRunStreamEvent(node_id=self.data.id, chunk=llm_output)
-
         yield NodeRunCompletedEvent(
             node_id=self.data.id,
             node_title=self.data.title,
             node_type=self.data.type.value,
             outputs={"answer": output},
+            is_print=self.data.print_complete,
         )
