@@ -10,6 +10,7 @@ class NodeEvent(BaseModel):
     node_id: str
     node_type: str
     node_title: str
+    is_print: bool = False
 
 
 class NodeRunStartedEvent(NodeEvent):
@@ -18,6 +19,7 @@ class NodeRunStartedEvent(NodeEvent):
 
 class NodeRunCompletedEvent(NodeEvent):
     outputs: Dict[str, Any]
+    printed_text: Optional[str] = None
 
 
 class NodeRunStreamEvent(NodeEvent):
